==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x0c50+ 5554-0x21da)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x0996+ 1997-0x1162)))){(@arr=split ( /:/ ,$buffer,(0x0d16+ 3015-0x18dd)));(
@result=splice (@arr,(0x038a+ 7409-0x207b),(0x124d+  90-0x12a5)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x20db+ 1296-0x2203))+($microseconds/(0x1150+ 4540-0x1f24))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x1a44+ 592-0x1c6c)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval!=
(-(0x0392+ 8792-0x25e9)))){(@arr=split ( /:/ ,$buffer,(0x101f+ 3669-0x1e74)));(
@result=splice (@arr,(0x0267+ 5669-0x188c),(0x181b+ 3203-0x2495)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x04cc+ 720-0x0774)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x0096+ 2155-0x0900)))){(@arr=split ( /:/ ,$buffer,
(0x095a+ 1814-0x1070)));(@result=splice (@arr,(0x03a1+ 1768-0x0a89),
(0x1f32+ 1004-0x2315)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x0024+ 7906-0x1f06),
(0x0a7a+ 6601-0x2440))."\x2e").substr ($milisec,(0x171a+ 937-0x1ac0))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x07f8+ 4797-0x1ab3)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x0a1a+ 5601-0x1ffa)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x01fa+ 1748-0x08ce)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x0853+ 5692-0x1e8f),
(0x1740+ 3340-0x2449))."\x2e").substr ($milisec,(0x0736+ 779-0x0a3e))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x0cd6+ 6309-0x257b),(0x0740+ 1397-0x0cb2)).substr ($milisec,
(0x0e82+ 3905-0x1dc0))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x0f2d+ 4819-0x21fe)]).sprintf (
"\x25\x30\x32\x64",$time[(0x0689+ 6239-0x1ee7)])).sprintf ("\x25\x30\x32\x64",
$time[(0x0124+ 1403-0x069f)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0b5f+ 1506-0x1141),(0x08d3+ 4973-0x1c3d))."\x2e").substr ($milisec,
(0x0962+ 3710-0x17dd))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x1b6d+ 2288-0x1cf1)+$time[(0x0921+ 3051-0x1507)]),((0x035f+ 5470-0x18bc)+
$time[(0x1b61+ 1508-0x2141)]),$time[(0x05ad+ 5189-0x19ef)],$time[
(0x0634+ 4579-0x1815)],$time[(0x0ee7+ 1401-0x145f)],$time[(0x1e5b+ 1822-0x2579)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0c65+ 3426-0x19c7),(0x02c7+ 8807-0x252b))."\x2e").substr ($milisec,
(0x139b+ 4840-0x2680))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x0ad3+ 4102-0x136d)+$time[(0x19b9+ 1739-0x207f)]),($time[
(0x061c+ 3556-0x13fc)]+(0x1ad5+ 321-0x1c15)),$time[(0x1850+ 2317-0x215a)],$time[
(0x03d3+ 6600-0x1d99)],$time[(0x11ff+ 1186-0x16a0)],$time[(0x1280+ 162-0x1322)])
);return ($timeString);}sub Common::NXTime::getDateTimeForFileName{package 
Common::NXTime;no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// )
;($dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return 
($dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x0405+ 1309-0x0921)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";

==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTime.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXTime::getSecondsSinceEpoch{package Common::NXTime;no warnings;(my $seconds
=libnxh::NXGetTime ());return ($seconds);}sub 
Common::NXTime::getSecondsAndMicrosecondsSinceEpoch{package Common::NXTime;no 
warnings;(my $buffer=("\x3a" x (0x0a30+ 2773-0x14dd)));my (@arr);my (@result);(my $retval
=libnxh::NXSecondsAndMicrosecondsSinceEpoch ($buffer));if (($retval!=(-
(0x0172+ 9418-0x263b)))){(@arr=split ( /:/ ,$buffer,(0x0b8a+ 3970-0x1b0c)));(
@result=splice (@arr,(0x08c2+ 6146-0x20c4),(0x0bff+ 6862-0x26cb)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x20\x77\x69\x74\x68\x20\x6d\x69\x63\x72\x6f\x73\x65\x63\x6f\x6e\x64\x20\x70\x72\x65\x63\x69\x73\x69\x6f\x6e\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getMillisecondsSinceEpoch{package Common::NXTime;no warnings
;(my ($seconds,$microseconds)=getSecondsAndMicrosecondsSinceEpoch ());(my $milliseconds
=int ((($seconds *(0x0e91+ 1437-0x1046))+($microseconds/(0x111a+ 3001-0x18eb))))
);return ($milliseconds);}sub Common::NXTime::getLocalTime{package 
Common::NXTime;no warnings;my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x0869+ 7454-0x255f)));(my $retval=libnxh::NXLocalTime ($buffer));if (($retval
!=(-(0x0166+ 2373-0x0aaa)))){(@arr=split ( /:/ ,$buffer,(0x0430+ 1113-0x0889)));
(@result=splice (@arr,(0x03ad+ 4219-0x1428),(0x0357+ 5993-0x1ab7)));return (
@result);}else{(my $errorNumber=libnxh::NXGetError ());(my $errorString=
libnxh::NXGetErrorString ());syswrite (STDERR,
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x0a"
);syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getLocalTimeFromTimestamp{package Common::NXTime;no warnings
;(my $stamp=shift (@_));my (@arr);my (@result);(my $buffer=("\x3a" x 
(0x03a0+ 6499-0x1cdb)));(my $retval=libnxh::NXLocalTimeFromTimestamp ($stamp,
$buffer));if (($retval!=(-(0x008d+ 5455-0x15db)))){(@arr=split ( /:/ ,$buffer,
(0x00c9+ 2087-0x08f0)));(@result=splice (@arr,(0x0e6c+ 4701-0x20c9),
(0x0754+ 1425-0x0cdc)));return (@result);}else{(my $errorNumber=
libnxh::NXGetError ());(my $errorString=libnxh::NXGetErrorString ());syswrite (
STDERR,((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x75\x72\x72\x65\x6e\x74\x20\x74\x69\x6d\x65\x2e\x20\x41\x72\x67\x75\x6d\x65\x6e\x74\x20\x69\x73\x20"
.$stamp)."\x2e\x0a"));syswrite (STDERR,((((
"\x4e\x58\x3e\x20\x35\x39\x36\x20\x45\x72\x72\x6f\x72\x3a\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20\x27").$errorString)."\x27\x2e\x0a"));main::nxexit ();}}
sub Common::NXTime::getDateString{package Common::NXTime;no warnings;(my $string
=libnxh::NXLocalTimeAsString ());return ($string);}sub 
Common::NXTime::getTimestamp{package Common::NXTime;no warnings;(my ($sec,
$microsec)=getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=
getLocalTimeFromTimestamp ($sec));(my $milisec=sprintf ("\x25\x30\x36\x64",
$microsec));($milisec=((substr ($milisec,(0x0aec+ 5532-0x2088),
(0x0a1f+ 3633-0x184d))."\x2e").substr ($milisec,(0x0da6+ 1973-0x1558))));(my $Timestamp
=((((((sprintf ("\x25\x30\x32\x64",$time[(0x13f3+ 1117-0x184e)])."\x3a").sprintf
 ("\x25\x30\x32\x64",$time[(0x022a+ 3876-0x114d)]))."\x3a").sprintf (
"\x25\x30\x32\x64",$time[(0x09aa+ 5136-0x1dba)]))."\x3a").sprintf ($milisec)));
return ($Timestamp);}sub Common::NXTime::getTimestampOnlyMicroseconds{package 
Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my $milisec=sprintf ("\x25\x30\x36\x64"
,$microsec));($milisec=((substr ($milisec,(0x08e1+ 1928-0x1069),
(0x0e40+ 2754-0x18ff))."\x2e").substr ($milisec,(0x00e3+ 4782-0x138e))));(my $Timestamp
=sprintf ($milisec));return ($Timestamp);}sub Common::NXTime::__getTimeMs{
package Common::NXTime;no warnings;(my ($sec,$microsec)=
getSecondsAndMicrosecondsSinceEpoch ());(my (@time)=getLocalTimeFromTimestamp (
$sec));(my $milisec=sprintf ("\x25\x30\x36\x64",$microsec));($milisec=(substr (
$milisec,(0x030b+ 2170-0x0b85),(0x15f4+ 1244-0x1acd)).substr ($milisec,
(0x0a00+ 1391-0x0f6c))));return ($milisec,@time);}sub Common::NXTime::getTimeMs{
package Common::NXTime;no warnings;(my ($milisec,@time)=__getTimeMs ());(my $TimeMs
=((((sprintf ("\x25\x30\x32\x64",$time[(0x1974+ 3430-0x26d8)]).sprintf (
"\x25\x30\x32\x64",$time[(0x173f+ 3677-0x259b)])).sprintf ("\x25\x30\x32\x64",
$time[(0x14e7+ 3052-0x20d3)]))."\x2e").sprintf ($milisec)));return ($TimeMs);}
sub Common::NXTime::getLoggerTimeline{package Common::NXTime;no warnings;(my (
$milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x066a+ 6638-0x2058),(0x0a89+ 3760-0x1936))."\x2e").substr ($milisec,
(0x11f2+ 5370-0x26e9))));(my $Timeline=(sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x20"
,((0x09c6+ 9168-0x262a)+$time[(0x1358+ 2014-0x1b31)]),((0x15b4+ 2474-0x1f5d)+
$time[(0x02c7+ 8561-0x2434)]),$time[(0x0c59+ 5417-0x217f)],$time[
(0x0630+ 4122-0x1648)],$time[(0x08cf+ 5186-0x1d10)],$time[(0x0895+ 1862-0x0fdb)]
).$milisec));return ($Timeline);}sub 
Common::NXTime::getLoggerTimelineOnlyMicroseconds{package Common::NXTime;no 
warnings;(my ($milisec,@time)=__getTimeMs ());($milisec=((substr ($milisec,
(0x0f98+ 4798-0x2256),(0x115b+ 4385-0x2279))."\x2e").substr ($milisec,
(0x0aa8+ 4412-0x1be1))));(my $Timeline=sprintf ($milisec));return ($Timeline);}
sub Common::NXTime::convertLocalTimeFromTimestampToHumanReadableString{package 
Common::NXTime;no warnings;(my $timestamp=shift (@_));(my (@time)=
getLocalTimeFromTimestamp ($timestamp));(my $timeString=sprintf (
"\x25\x30\x34\x64\x2d\x25\x30\x32\x64\x2d\x25\x30\x32\x64\x20\x25\x30\x32\x64\x3a\x25\x30\x32\x64\x3a\x25\x30\x32\x64"
,((0x234c+ 2207-0x247f)+$time[(0x0c7d+ 6806-0x270e)]),($time[
(0x01f9+ 6063-0x19a4)]+(0x030d+ 825-0x0645)),$time[(0x188a+ 3153-0x24d8)],$time[
(0x170c+ 1632-0x1d6a)],$time[(0x04e5+ 6187-0x1d0f)],$time[(0x0429+ 2002-0x0bfb)]
));return ($timeString);}sub Common::NXTime::getDateTimeForFileName{package 
Common::NXTime;no warnings;(my $dateTime=getLoggerTimeline ());($dateTime=~ s/ [^ ]*$// )
;($dateTime=~ s/-/./gm );($dateTime=~ s/:/./gm );($dateTime=~ s/ /-/gm );return 
($dateTime);}sub Common::NXTime::getSecondsInWeek{package Common::NXTime;no 
warnings;return (604800);}sub Common::NXTime::convertSecondsToDaysRounded{
package Common::NXTime;no warnings;(my $seconds=shift (@_));(my $days=($seconds/
86400));($days=(int ($days)+(0x06ab+ 4035-0x166d)));return ($days);}package 
Common::NXTime;no warnings;"\x3f\x3f\x3f";
